# Descriptives

source("Scripts/ols/ols_time_spent.R")
source("Scripts/ols/ols_quiz.R")
data <- left_join(data, select(quiz_data, id, percentage_correct), by = "id")

data <- data %>%
  mutate(
    Control_Not_Pred = ifelse(Matching_Group == "Control Not Pred", 1, 0),
    Control_Pred = ifelse(Matching_Group == "Control Pred", 1, 0),
    Opt_Not_Pred = ifelse(Matching_Group == "Opt Not Pred", 1, 0),
    Opt_Pred = ifelse(Matching_Group == "Opt Pred", 1, 0),
    Treat_Not_Pred = ifelse(Matching_Group == "Treat Not Pred", 1, 0),
    Treat_Pred = ifelse(Matching_Group == "Treat Pred", 1, 0),
    Opt_Treatment = Dummy_Vol_Treated+Dummy_no_info,
    Control = ifelse(Treatment_A=="Not_Treated",1,0)
  )

data$Conseq_score<- data$Conseq_Money+data$Conseq_UGS
table(data$QFIncome)
data <- data %>%
  mutate(income = ifelse(QFIncome == 0, NA, QFIncome))
table(data$Dummy_Vol_Treated)
table(data$Dummy_no_info)
# Compute summary statistics for each group
summary_stats <- data %>%
  summarise(
    # Number of respondents per group
    Full_Sample_n = n(),
    Dummy_Treated_n = sum(Dummy_Treated, na.rm = TRUE),
    Dummy_Vol_Treated_n = sum(Dummy_Vol_Treated, na.rm = TRUE),
    Dummy_no_info_n = sum(Dummy_no_info, na.rm = TRUE),
    Control_Not_Pred_n = sum(Control_Not_Pred, na.rm = TRUE),
    Control_Pred_n = sum(Control_Pred, na.rm = TRUE),
    Opt_Not_Pred_n = sum(Opt_Not_Pred, na.rm = TRUE),
    Opt_Pred_n = sum(Opt_Pred, na.rm = TRUE),
    Treat_Not_Pred_n = sum(Treat_Not_Pred, na.rm = TRUE),
    Treat_Pred_n = sum(Treat_Pred, na.rm = TRUE),
    Opt_Treatment_n = sum(Opt_Treatment, na.rm = TRUE),
    Control_n = sum(Control, na.rm = TRUE),
    
    
    # Gender (% Female)
    Full_Sample_Gender = mean(Gender_female, na.rm = TRUE) * 100,
    Dummy_Treated_Gender = mean(Gender_female[Dummy_Treated == 1], na.rm = TRUE) * 100,
    Dummy_Vol_Treated_Gender = mean(Gender_female[Dummy_Vol_Treated == 1], na.rm = TRUE) * 100,
    Dummy_no_info_Gender = mean(Gender_female[Dummy_no_info == 1], na.rm = TRUE) * 100,
    Control_Not_Pred_Gender = mean(Gender_female[Control_Not_Pred == 1], na.rm = TRUE) * 100,
    Control_Pred_Gender = mean(Gender_female[Control_Pred == 1], na.rm = TRUE) * 100,
    Opt_Not_Pred_Gender = mean(Gender_female[Opt_Not_Pred == 1], na.rm = TRUE) * 100,
    Opt_Pred_Gender = mean(Gender_female[Opt_Pred == 1], na.rm = TRUE) * 100,
    Treat_Not_Pred_Gender = mean(Gender_female[Treat_Not_Pred == 1], na.rm = TRUE) * 100,
    Treat_Pred_Gender = mean(Gender_female[Treat_Pred == 1], na.rm = TRUE) * 100,
    Opt_Treatment_Gender = mean(Gender_female[Opt_Treatment == 1], na.rm = TRUE) * 100,
    Control_Gender = mean(Gender_female[Control == 1], na.rm = TRUE) * 100,
    
  
    # University Degree (%)
    Full_Sample_UniDegree = mean(Uni_degree, na.rm = TRUE) * 100,
    Dummy_Treated_UniDegree = mean(Uni_degree[Dummy_Treated == 1], na.rm = TRUE) * 100,
    Dummy_Vol_Treated_UniDegree = mean(Uni_degree[Dummy_Vol_Treated == 1], na.rm = TRUE) * 100,
    Dummy_no_info_UniDegree = mean(Uni_degree[Dummy_no_info == 1], na.rm = TRUE) * 100,
    Control_Not_Pred_UniDegree = mean(Uni_degree[Control_Not_Pred == 1], na.rm = TRUE) * 100,
    Control_Pred_UniDegree = mean(Uni_degree[Control_Pred == 1], na.rm = TRUE) * 100,
    Opt_Not_Pred_UniDegree = mean(Uni_degree[Opt_Not_Pred == 1], na.rm = TRUE) * 100,
    Opt_Pred_UniDegree = mean(Uni_degree[Opt_Pred == 1], na.rm = TRUE) * 100,
    Treat_Not_Pred_UniDegree = mean(Uni_degree[Treat_Not_Pred == 1], na.rm = TRUE) * 100,
    Treat_Pred_UniDegree = mean(Uni_degree[Treat_Pred == 1], na.rm = TRUE) * 100,
    Opt_Treatment_UniDegree = mean(Uni_degree[Opt_Treatment == 1], na.rm = TRUE) * 100,
    Control_UniDegree = mean(Uni_degree[Control == 1], na.rm = TRUE) * 100,
    
    # Income Proportion (% for each category 1,2,3,4) for all groups
    Full_Sample_Income_1 = mean(income == 1, na.rm = TRUE) * 100,
    Full_Sample_Income_2 = mean(income == 2, na.rm = TRUE) * 100,
    Full_Sample_Income_3 = mean(income == 3, na.rm = TRUE) * 100,
    Full_Sample_Income_4 = mean(income == 4, na.rm = TRUE) * 100,
    
    Dummy_Treated_Income_1 = mean(income[Dummy_Treated == 1] == 1, na.rm = TRUE) * 100,
    Dummy_Treated_Income_2 = mean(income[Dummy_Treated == 1] == 2, na.rm = TRUE) * 100,
    Dummy_Treated_Income_3 = mean(income[Dummy_Treated == 1] == 3, na.rm = TRUE) * 100,
    Dummy_Treated_Income_4 = mean(income[Dummy_Treated == 1] == 4, na.rm = TRUE) * 100,
    
    Dummy_no_info_Income_1 = mean(income[Dummy_no_info == 1] == 1, na.rm = TRUE) * 100,
    Dummy_no_info_Income_2 = mean(income[Dummy_no_info == 1] == 2, na.rm = TRUE) * 100,
    Dummy_no_info_Income_3 = mean(income[Dummy_no_info == 1] == 3, na.rm = TRUE) * 100,
    Dummy_no_info_Income_4 = mean(income[Dummy_no_info == 1] == 4, na.rm = TRUE) * 100,
    
    Dummy_Vol_Treated_Income_1 = mean(income[Dummy_Vol_Treated == 1] == 1, na.rm = TRUE) * 100,
    Dummy_Vol_Treated_Income_2 = mean(income[Dummy_Vol_Treated == 1] == 2, na.rm = TRUE) * 100,
    Dummy_Vol_Treated_Income_3 = mean(income[Dummy_Vol_Treated == 1] == 3, na.rm = TRUE) * 100,
    Dummy_Vol_Treated_Income_4 = mean(income[Dummy_Vol_Treated == 1] == 4, na.rm = TRUE) * 100,
    
    Control_Not_Pred_Income_1 = mean(income[Control_Not_Pred == 1] == 1, na.rm = TRUE) * 100,
    Control_Not_Pred_Income_2 = mean(income[Control_Not_Pred == 1] == 2, na.rm = TRUE) * 100,
    Control_Not_Pred_Income_3 = mean(income[Control_Not_Pred == 1] == 3, na.rm = TRUE) * 100,
    Control_Not_Pred_Income_4 = mean(income[Control_Not_Pred == 1] == 4, na.rm = TRUE) * 100,
    
    Control_Pred_Income_1 = mean(income[Control_Pred == 1] == 1, na.rm = TRUE) * 100,
    Control_Pred_Income_2 = mean(income[Control_Pred == 1] == 2, na.rm = TRUE) * 100,
    Control_Pred_Income_3 = mean(income[Control_Pred == 1] == 3, na.rm = TRUE) * 100,
    Control_Pred_Income_4 = mean(income[Control_Pred == 1] == 4, na.rm = TRUE) * 100,
    
    Opt_Not_Pred_Income_1 = mean(income[Opt_Not_Pred == 1] == 1, na.rm = TRUE) * 100,
    Opt_Not_Pred_Income_2 = mean(income[Opt_Not_Pred == 1] == 2, na.rm = TRUE) * 100,
    Opt_Not_Pred_Income_3 = mean(income[Opt_Not_Pred == 1] == 3, na.rm = TRUE) * 100,
    Opt_Not_Pred_Income_4 = mean(income[Opt_Not_Pred == 1] == 4, na.rm = TRUE) * 100,
    
    Opt_Pred_Income_1 = mean(income[Opt_Pred == 1] == 1, na.rm = TRUE) * 100,
    Opt_Pred_Income_2 = mean(income[Opt_Pred == 1] == 2, na.rm = TRUE) * 100,
    Opt_Pred_Income_3 = mean(income[Opt_Pred == 1] == 3, na.rm = TRUE) * 100,
    Opt_Pred_Income_4 = mean(income[Opt_Pred == 1] == 4, na.rm = TRUE) * 100,
    
    Treat_Not_Pred_Income_1 = mean(income[Treat_Not_Pred == 1] == 1, na.rm = TRUE) * 100,
    Treat_Not_Pred_Income_2 = mean(income[Treat_Not_Pred == 1] == 2, na.rm = TRUE) * 100,
    Treat_Not_Pred_Income_3 = mean(income[Treat_Not_Pred == 1] == 3, na.rm = TRUE) * 100,
    Treat_Not_Pred_Income_4 = mean(income[Treat_Not_Pred == 1] == 4, na.rm = TRUE) * 100,
    
    Treat_Pred_Income_1 = mean(income[Treat_Pred == 1] == 1, na.rm = TRUE) * 100,
    Treat_Pred_Income_2 = mean(income[Treat_Pred == 1] == 2, na.rm = TRUE) * 100,
    Treat_Pred_Income_3 = mean(income[Treat_Pred == 1] == 3, na.rm = TRUE) * 100,
    Treat_Pred_Income_4 = mean(income[Treat_Pred == 1] == 4, na.rm = TRUE) * 100,
    
    Opt_Treatment_Income_1 = mean(income[Opt_Treatment == 1] == 1, na.rm = TRUE) * 100,
    Opt_Treatment_Income_2 = mean(income[Opt_Treatment == 1] == 2, na.rm = TRUE) * 100,
    Opt_Treatment_Income_3 = mean(income[Opt_Treatment == 1] == 3, na.rm = TRUE) * 100,
    Opt_Treatment_Income_4 = mean(income[Opt_Treatment == 1] == 4, na.rm = TRUE) * 100,
    
    Control_Income_1 = mean(income[Control == 1] == 1, na.rm = TRUE) * 100,
    Control_Income_2 = mean(income[Control == 1] == 2, na.rm = TRUE) * 100,
    Control_Income_3 = mean(income[Control == 1] == 3, na.rm = TRUE) * 100,
    Control_Income_4 = mean(income[Control == 1] == 4, na.rm = TRUE) * 100,
    
    # Continuous Variables (Mean)
    
    Full_Sample_Age = mean(Age, na.rm = TRUE),
    Dummy_Treated_Age = mean(Age[Dummy_Treated == 1], na.rm = TRUE),
    Dummy_Vol_Treated_Age = mean(Age[Dummy_Vol_Treated == 1], na.rm = TRUE),
    Dummy_no_info_Age = mean(Age[Dummy_no_info == 1], na.rm = TRUE),
    Control_Not_Pred_Age = mean(Age[Control_Not_Pred == 1], na.rm = TRUE),
    Control_Pred_Age = mean(Age[Control_Pred == 1], na.rm = TRUE),
    Opt_Not_Pred_Age = mean(Age[Opt_Not_Pred == 1], na.rm = TRUE),
    Opt_Pred_Age = mean(Age[Opt_Pred == 1], na.rm = TRUE),
    Treat_Not_Pred_Age = mean(Age[Treat_Not_Pred == 1], na.rm = TRUE),
    Treat_Pred_Age = mean(Age[Treat_Pred == 1], na.rm = TRUE),
    Opt_Treatment_Age = mean(Age[Opt_Treatment == 1], na.rm = TRUE),
    Control_Age = mean(Age[Control == 1], na.rm = TRUE),
    
    Full_Sample_NR = mean(Z_Mean_NR, na.rm = TRUE),
    Dummy_Treated_NR = mean(Z_Mean_NR[Dummy_Treated == 1], na.rm = TRUE),
    Dummy_Vol_Treated_NR = mean(Z_Mean_NR[Dummy_Vol_Treated == 1], na.rm = TRUE),
    Dummy_no_info_NR = mean(Z_Mean_NR[Dummy_no_info == 1], na.rm = TRUE),
    Control_Not_Pred_NR = mean(Z_Mean_NR[Control_Not_Pred == 1], na.rm = TRUE),
    Control_Pred_NR = mean(Z_Mean_NR[Control_Pred == 1], na.rm = TRUE),
    Opt_Not_Pred_NR = mean(Z_Mean_NR[Opt_Not_Pred == 1], na.rm = TRUE),
    Opt_Pred_NR = mean(Z_Mean_NR[Opt_Pred == 1], na.rm = TRUE),
    Treat_Not_Pred_NR = mean(Z_Mean_NR[Treat_Not_Pred == 1], na.rm = TRUE),
    Treat_Pred_NR = mean(Z_Mean_NR[Treat_Pred == 1], na.rm = TRUE),
    Opt_Treatment_NR = mean(Z_Mean_NR[Opt_Treatment == 1], na.rm = TRUE),
    Control_NR = mean(Z_Mean_NR[Control == 1], na.rm = TRUE),
    
    Full_Sample_Conseq = mean(Conseq_score, na.rm = TRUE),
    Dummy_Treated_Conseq = mean(Conseq_score[Dummy_Treated == 1], na.rm = TRUE),
    Dummy_Vol_Treated_Conseq = mean(Conseq_score[Dummy_Vol_Treated == 1], na.rm = TRUE),
    Dummy_no_info_Conseq = mean(Conseq_score[Dummy_no_info == 1], na.rm = TRUE),
    Control_Not_Pred_Conseq = mean(Conseq_score[Control_Not_Pred == 1], na.rm = TRUE),
    Control_Pred_Conseq = mean(Conseq_score[Control_Pred == 1], na.rm = TRUE),
    Opt_Not_Pred_Conseq = mean(Conseq_score[Opt_Not_Pred == 1], na.rm = TRUE),
    Opt_Pred_Conseq = mean(Conseq_score[Opt_Pred == 1], na.rm = TRUE),
    Treat_Not_Pred_Conseq = mean(Conseq_score[Treat_Not_Pred == 1], na.rm = TRUE),
    Treat_Pred_Conseq = mean(Conseq_score[Treat_Pred == 1], na.rm = TRUE),
    Opt_Treatment_Conseq = mean(Conseq_score[Opt_Treatment == 1], na.rm = TRUE),
    Control_Conseq = mean(Conseq_score[Control == 1], na.rm = TRUE),
    
    Full_Sample_Correct = mean(percentage_correct, na.rm = TRUE),
    Dummy_Treated_Correct = mean(percentage_correct[Dummy_Treated == 1], na.rm = TRUE),
    Dummy_Vol_Treated_Correct = mean(percentage_correct[Dummy_Vol_Treated == 1], na.rm = TRUE),
    Dummy_no_info_Correct = mean(percentage_correct[Dummy_no_info == 1], na.rm = TRUE),
    Control_Not_Pred_Correct = mean(percentage_correct[Control_Not_Pred == 1], na.rm = TRUE),
    Control_Pred_Correct = mean(percentage_correct[Control_Pred == 1], na.rm = TRUE),
    Opt_Not_Pred_Correct = mean(percentage_correct[Opt_Not_Pred == 1], na.rm = TRUE),
    Opt_Pred_Correct = mean(percentage_correct[Opt_Pred == 1], na.rm = TRUE),
    Treat_Not_Pred_Correct = mean(percentage_correct[Treat_Not_Pred == 1], na.rm = TRUE),
    Treat_Pred_Correct = mean(percentage_correct[Treat_Pred == 1], na.rm = TRUE),
    Opt_Treatment_Correct = mean(percentage_correct[Opt_Treatment == 1], na.rm = TRUE),
    Control_Correct = mean(percentage_correct[Control == 1], na.rm = TRUE),
    
    Full_Sample_InterviewTime  = mean(interviewtime_net_clean, na.rm = TRUE),
    Dummy_Treated_InterviewTime  = mean(interviewtime_net_clean[Dummy_Treated == 1], na.rm = TRUE),
    Dummy_Vol_Treated_InterviewTime  = mean(interviewtime_net_clean[Dummy_Vol_Treated == 1], na.rm = TRUE),
    Dummy_no_info_InterviewTime  = mean(interviewtime_net_clean[Dummy_no_info == 1], na.rm = TRUE),
    Control_Not_Pred_InterviewTime  = mean(interviewtime_net_clean[Control_Not_Pred == 1], na.rm = TRUE),
    Control_Pred_InterviewTime  = mean(interviewtime_net_clean[Control_Pred == 1], na.rm = TRUE),
    Opt_Not_Pred_InterviewTime  = mean(interviewtime_net_clean[Opt_Not_Pred == 1], na.rm = TRUE),
    Opt_Pred_InterviewTime  = mean(interviewtime_net_clean[Opt_Pred == 1], na.rm = TRUE),
    Treat_Not_Pred_InterviewTime  = mean(interviewtime_net_clean[Treat_Not_Pred == 1], na.rm = TRUE),
    Treat_Pred_InterviewTime  = mean(interviewtime_net_clean[Treat_Pred == 1], na.rm = TRUE),
    Opt_Treatment_InterviewTime  = mean(interviewtime_net_clean[Opt_Treatment == 1], na.rm = TRUE),
    Control_InterviewTime  = mean(interviewtime_net_clean[Control == 1], na.rm = TRUE),
    

    Full_Sample_CC_time  = mean(CC_time_mean_clean, na.rm = TRUE),
    Dummy_Treated_CC_time  = mean(CC_time_mean_clean[Dummy_Treated == 1], na.rm = TRUE),
    Dummy_Vol_Treated_CC_time  = mean(CC_time_mean_clean[Dummy_Vol_Treated == 1], na.rm = TRUE),
    Dummy_no_info_CC_time  = mean(CC_time_mean_clean[Dummy_no_info == 1], na.rm = TRUE),
    Control_Not_Pred_CC_time  = mean(CC_time_mean_clean[Control_Not_Pred == 1], na.rm = TRUE),
    Control_Pred_CC_time  = mean(CC_time_mean_clean[Control_Pred == 1], na.rm = TRUE),
    Opt_Not_Pred_CC_time  = mean(CC_time_mean_clean[Opt_Not_Pred == 1], na.rm = TRUE),
    Opt_Pred_CC_time  = mean(CC_time_mean_clean[Opt_Pred == 1], na.rm = TRUE),
    Treat_Not_Pred_CC_time  = mean(CC_time_mean_clean[Treat_Not_Pred == 1], na.rm = TRUE),
    Treat_Pred_CC_time  = mean(CC_time_mean_clean[Treat_Pred == 1], na.rm = TRUE),
    Opt_Treatment_CC_time  = mean(CC_time_mean_clean[Opt_Treatment == 1], na.rm = TRUE),
    Control_CC_time  = mean(CC_time_mean_clean[Control == 1], na.rm = TRUE)
    
  )


write.csv(summary_stats,"Data/descriptives.csv", row.names = F)
write.table(summary_stats, "Data/descriptives.txt", sep="\t")



# Names of the variables in the first Column:
categories <- c("Gender", "Proportion Female:", "Age", "Net Houshold Income",
                "Less than 1500€", "1500€ - 3000€", 
                "300€- 4000€", "More than 4000€",
                "Education", "University degree", "No University degree",
                "NR-Index", "Correct quiz question", "Consequentiality score",
                "Net interview time", "Mean Choice Card time", "Number of respondents")



# Create the data frame
table_df <- data.frame(Category = categories, 
                       Sample = rep(NA, length(categories)),
                       Treated = rep(NA, length(categories)),
                       Opt_Treatment = rep(NA, length(categories)),
                       Control = rep(NA, length(categories)),
                       Vol_Treated = rep(NA, length(categories)),
                       No_Info = rep(NA, length(categories)),
                       Treated_Predicted = rep(NA, length(categories)),
                       Treated_Not_Predicted = rep(NA, length(categories)),
                       Opt_Treatment_Predicted = rep(NA, length(categories)),
                       Opt_Treatment_Not_Predicted = rep(NA, length(categories)),
                       Control_Predicted = rep(NA, length(categories)),
                       Control_Not_Predicted = rep(NA, length(categories)))


table_df$Sample[2:2] <-       round(summary_stats$Full_Sample_Gender[1:1],2)  # Ensure the counts match the categories
table_df$Sample[3:3] <-       round(summary_stats$Full_Sample_Age[1:1],2)   # Ensure the counts match the categories
table_df$Sample[5:5] <-       round(summary_stats$Full_Sample_Income_1[1:1],2)   # Ensure the counts match the categories
table_df$Sample[6:6] <-       round(summary_stats$Full_Sample_Income_2[1:1],2)   # Ensure the counts match the categories
table_df$Sample[7:7] <-       round(summary_stats$Full_Sample_Income_3[1:1],2)   # Ensure the counts match the categories
table_df$Sample[8:8] <-       round(summary_stats$Full_Sample_Income_4[1:1],2)   # Ensure the counts match the categories
table_df$Sample[10:10] <-     round(summary_stats$Full_Sample_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Sample[11:11] <- round(100-summary_stats$Full_Sample_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Sample[12:12] <-     round(summary_stats$Full_Sample_NR[1:1],2)   # Ensure the counts match the categories
table_df$Sample[13:13] <-     round(summary_stats$Full_Sample_Correct [1:1],2)   # Ensure the counts match the categories
table_df$Sample[14:14] <-     round(summary_stats$Full_Sample_Conseq [1:1],2)   # Ensure the counts match the categories
table_df$Sample[15:15] <-     round(summary_stats$Full_Sample_InterviewTime[1:1],0)   # Ensure the counts match the categories
table_df$Sample[16:16] <-     round(summary_stats$Full_Sample_CC_time[1:1],2)   # Ensure the counts match the categories
table_df$Sample[17:17] <-     round(summary_stats$Full_Sample_n[1:1],0)   # Ensure the counts match the categories

table_df$Treated[2:2] <-       round(summary_stats$Dummy_Treated_Gender[1:1],2)  # Ensure the counts match the categories
table_df$Treated[3:3] <-       round(summary_stats$Dummy_Treated_Age[1:1],2)   # Ensure the counts match the categories
table_df$Treated[5:5] <-       round(summary_stats$Dummy_Treated_Income_1[1:1],2)   # Ensure the counts match the categories
table_df$Treated[6:6] <-       round(summary_stats$Dummy_Treated_Income_2[1:1],2)   # Ensure the counts match the categories
table_df$Treated[7:7] <-       round(summary_stats$Dummy_Treated_Income_3[1:1],2)   # Ensure the counts match the categories
table_df$Treated[8:8] <-       round(summary_stats$Dummy_Treated_Income_4[1:1],2)   # Ensure the counts match the categories
table_df$Treated[10:10] <-     round(summary_stats$Dummy_Treated_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Treated[11:11] <- round(100-summary_stats$Dummy_Treated_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Treated[12:12] <-     round(summary_stats$Dummy_Treated_NR[1:1],2)   # Ensure the counts match the categories
table_df$Treated[13:13] <-     round(summary_stats$Dummy_Treated_Correct [1:1],2)   # Ensure the counts match the categories
table_df$Treated[14:14] <-     round(summary_stats$Dummy_Treated_Conseq [1:1],2)   # Ensure the counts match the categories
table_df$Treated[15:15] <-     round(summary_stats$Dummy_Treated_InterviewTime[1:1],0)   # Ensure the counts match the categories
table_df$Treated[16:16] <-     round(summary_stats$Dummy_Treated_CC_time[1:1],2)   # Ensure the counts match the categories
table_df$Treated[17:17] <-     round(summary_stats$Dummy_Treated_n[1:1],0)   # Ensure the counts match the categories


table_df$Opt_Treatment[2:2] <-       round(summary_stats$Opt_Treatment_Gender[1:1],2)  # Ensure the counts match the categories
table_df$Opt_Treatment[3:3] <-       round(summary_stats$Opt_Treatment_Age[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment[5:5] <-       round(summary_stats$Opt_Treatment_Income_1[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment[6:6] <-       round(summary_stats$Opt_Treatment_Income_2[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment[7:7] <-       round(summary_stats$Opt_Treatment_Income_3[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment[8:8] <-       round(summary_stats$Opt_Treatment_Income_4[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment[10:10] <-     round(summary_stats$Opt_Treatment_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment[11:11] <- round(100-summary_stats$Opt_Treatment_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment[12:12] <-     round(summary_stats$Opt_Treatment_NR[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment[13:13] <-     round(summary_stats$Opt_Treatment_Correct [1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment[14:14] <-     round(summary_stats$Opt_Treatment_Conseq [1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment[15:15] <-     round(summary_stats$Opt_Treatment_InterviewTime[1:1],0)   # Ensure the counts match the categories
table_df$Opt_Treatment[16:16] <-     round(summary_stats$Opt_Treatment_CC_time[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment[17:17] <-     round(summary_stats$Opt_Treatment_n[1:1],0) 


table_df$Control[2:2] <-       round(summary_stats$Control_Gender[1:1],2)  # Ensure the counts match the categories
table_df$Control[3:3] <-       round(summary_stats$Control_Age[1:1],2)   # Ensure the counts match the categories
table_df$Control[5:5] <-       round(summary_stats$Control_Income_1[1:1],2)   # Ensure the counts match the categories
table_df$Control[6:6] <-       round(summary_stats$Control_Income_2[1:1],2)   # Ensure the counts match the categories
table_df$Control[7:7] <-       round(summary_stats$Control_Income_3[1:1],2)   # Ensure the counts match the categories
table_df$Control[8:8] <-       round(summary_stats$Control_Income_4[1:1],2)   # Ensure the counts match the categories
table_df$Control[10:10] <-     round(summary_stats$Control_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Control[11:11] <- round(100-summary_stats$Control_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Control[12:12] <-     round(summary_stats$Control_NR[1:1],2)   # Ensure the counts match the categories
table_df$Control[13:13] <-     round(summary_stats$Control_Correct [1:1],2)   # Ensure the counts match the categories
table_df$Control[14:14] <-     round(summary_stats$Control_Conseq [1:1],2)   # Ensure the counts match the categories
table_df$Control[15:15] <-     round(summary_stats$Control_InterviewTime[1:1],0)   # Ensure the counts match the categories
table_df$Control[16:16] <-     round(summary_stats$Control_CC_time[1:1],2)   # Ensure the counts match the categories
table_df$Control[17:17] <-     round(summary_stats$Control_n[1:1],0)   # Ensure the counts match the categories
# Ensure the counts match the categories


table_df$Vol_Treated[2:2] <-       round(summary_stats$Dummy_Vol_Treated_Gender[1:1],2)  # Ensure the counts match the categories
table_df$Vol_Treated[3:3] <-       round(summary_stats$Dummy_Vol_Treated_Age[1:1],2)   # Ensure the counts match the categories
table_df$Vol_Treated[5:5] <-       round(summary_stats$Dummy_Vol_Treated_Income_1[1:1],2)   # Ensure the counts match the categories
table_df$Vol_Treated[6:6] <-       round(summary_stats$Dummy_Vol_Treated_Income_2[1:1],2)   # Ensure the counts match the categories
table_df$Vol_Treated[7:7] <-       round(summary_stats$Dummy_Vol_Treated_Income_3[1:1],2)   # Ensure the counts match the categories
table_df$Vol_Treated[8:8] <-       round(summary_stats$Dummy_Vol_Treated_Income_4[1:1],2)   # Ensure the counts match the categories
table_df$Vol_Treated[10:10] <-     round(summary_stats$Dummy_Vol_Treated_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Vol_Treated[11:11] <- round(100-summary_stats$Dummy_Vol_Treated_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Vol_Treated[12:12] <-     round(summary_stats$Dummy_Vol_Treated_NR[1:1],2)   # Ensure the counts match the categories
table_df$Vol_Treated[13:13] <-     round(summary_stats$Dummy_Vol_Treated_Correct [1:1],2)   # Ensure the counts match the categories
table_df$Vol_Treated[14:14] <-     round(summary_stats$Dummy_Vol_Treated_Conseq [1:1],2)   # Ensure the counts match the categories
table_df$Vol_Treated[15:15] <-     round(summary_stats$Dummy_Vol_Treated_InterviewTime[1:1],0)   # Ensure the counts match the categories
table_df$Vol_Treated[16:16] <-     round(summary_stats$Dummy_Vol_Treated_CC_time[1:1],2)   # Ensure the counts match the categories
table_df$Vol_Treated[17:17] <-     round(summary_stats$Dummy_Vol_Treated_n[1:1],0) 

table_df$No_Info[2:2] <-       round(summary_stats$Dummy_no_info_Gender[1:1],2)  # Ensure the counts match the categories
table_df$No_Info[3:3] <-       round(summary_stats$Dummy_no_info_Age[1:1],2)   # Ensure the counts match the categories
table_df$No_Info[5:5] <-       round(summary_stats$Dummy_no_info_Income_1[1:1],2)   # Ensure the counts match the categories
table_df$No_Info[6:6] <-       round(summary_stats$Dummy_no_info_Income_2[1:1],2)   # Ensure the counts match the categories
table_df$No_Info[7:7] <-       round(summary_stats$Dummy_no_info_Income_3[1:1],2)   # Ensure the counts match the categories
table_df$No_Info[8:8] <-       round(summary_stats$Dummy_no_info_Income_4[1:1],2)   # Ensure the counts match the categories
table_df$No_Info[10:10] <-     round(summary_stats$Dummy_no_info_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$No_Info[11:11] <- round(100-summary_stats$Dummy_no_info_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$No_Info[12:12] <-     round(summary_stats$Dummy_no_info_NR[1:1],2)   # Ensure the counts match the categories
table_df$No_Info[13:13] <-     round(summary_stats$Dummy_no_info_Correct [1:1],2)   # Ensure the counts match the categories
table_df$No_Info[14:14] <-     round(summary_stats$Dummy_no_info_Conseq [1:1],2)   # Ensure the counts match the categories
table_df$No_Info[15:15] <-     round(summary_stats$Dummy_no_info_InterviewTime[1:1],0)   # Ensure the counts match the categories
table_df$No_Info[16:16] <-     round(summary_stats$Dummy_no_info_CC_time[1:1],2)   # Ensure the counts match the categories
table_df$No_Info[17:17] <-     round(summary_stats$Dummy_no_info_n[1:1],0) 


table_df$Treated_Predicted[2:2] <-       round(summary_stats$Treat_Pred_Gender[1:1],2)  # Ensure the counts match the categories
table_df$Treated_Predicted[3:3] <-       round(summary_stats$Treat_Pred_Age[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Predicted[5:5] <-       round(summary_stats$Treat_Pred_Income_1[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Predicted[6:6] <-       round(summary_stats$Treat_Pred_Income_2[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Predicted[7:7] <-       round(summary_stats$Treat_Pred_Income_3[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Predicted[8:8] <-       round(summary_stats$Treat_Pred_Income_4[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Predicted[10:10] <-     round(summary_stats$Treat_Pred_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Predicted[11:11] <- round(100-summary_stats$Treat_Pred_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Predicted[12:12] <-     round(summary_stats$Treat_Pred_NR[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Predicted[13:13] <-     round(summary_stats$Treat_Pred_Correct [1:1],2)   # Ensure the counts match the categories
table_df$Treated_Predicted[14:14] <-     round(summary_stats$Treat_Pred_Conseq [1:1],2)   # Ensure the counts match the categories
table_df$Treated_Predicted[15:15] <-     round(summary_stats$Treat_Pred_InterviewTime[1:1],0)   # Ensure the counts match the categories
table_df$Treated_Predicted[16:16] <-     round(summary_stats$Treat_Pred_CC_time[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Predicted[17:17] <-     round(summary_stats$Treat_Pred_n[1:1],0) 


table_df$Treated_Not_Predicted[2:2] <-       round(summary_stats$Treat_Not_Pred_Gender[1:1],2)  # Ensure the counts match the categories
table_df$Treated_Not_Predicted[3:3] <-       round(summary_stats$Treat_Not_Pred_Age[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Not_Predicted[5:5] <-       round(summary_stats$Treat_Not_Pred_Income_1[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Not_Predicted[6:6] <-       round(summary_stats$Treat_Not_Pred_Income_2[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Not_Predicted[7:7] <-       round(summary_stats$Treat_Not_Pred_Income_3[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Not_Predicted[8:8] <-       round(summary_stats$Treat_Not_Pred_Income_4[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Not_Predicted[10:10] <-     round(summary_stats$Treat_Not_Pred_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Not_Predicted[11:11] <- round(100-summary_stats$Treat_Not_Pred_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Not_Predicted[12:12] <-     round(summary_stats$Treat_Not_Pred_NR[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Not_Predicted[13:13] <-     round(summary_stats$Treat_Not_Pred_Correct [1:1],2)   # Ensure the counts match the categories
table_df$Treated_Not_Predicted[14:14] <-     round(summary_stats$Treat_Not_Pred_Conseq [1:1],2)   # Ensure the counts match the categories
table_df$Treated_Not_Predicted[15:15] <-     round(summary_stats$Treat_Not_Pred_InterviewTime[1:1],0)   # Ensure the counts match the categories
table_df$Treated_Not_Predicted[16:16] <-     round(summary_stats$Treat_Not_Pred_CC_time[1:1],2)   # Ensure the counts match the categories
table_df$Treated_Not_Predicted[17:17] <-     round(summary_stats$Treat_Not_Pred_n[1:1],0) 



table_df$Opt_Treatment_Predicted[2:2] <-       round(summary_stats$Opt_Pred_Gender[1:1],2)  # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[3:3] <-       round(summary_stats$Opt_Pred_Age[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[5:5] <-       round(summary_stats$Opt_Pred_Income_1[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[6:6] <-       round(summary_stats$Opt_Pred_Income_2[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[7:7] <-       round(summary_stats$Opt_Pred_Income_3[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[8:8] <-       round(summary_stats$Opt_Pred_Income_4[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[10:10] <-     round(summary_stats$Opt_Pred_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[11:11] <- round(100-summary_stats$Opt_Pred_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[12:12] <-     round(summary_stats$Opt_Pred_NR[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[13:13] <-     round(summary_stats$Opt_Pred_Correct [1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[14:14] <-     round(summary_stats$Opt_Pred_Conseq [1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[15:15] <-     round(summary_stats$Opt_Pred_InterviewTime[1:1],0)   # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[16:16] <-     round(summary_stats$Opt_Pred_CC_time[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Predicted[17:17] <-     round(summary_stats$Opt_Pred_n[1:1],0)

table_df$Opt_Treatment_Not_Predicted[2:2] <-       round(summary_stats$Opt_Not_Pred_Gender[1:1],2)  # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[3:3] <-       round(summary_stats$Opt_Not_Pred_Age[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[5:5] <-       round(summary_stats$Opt_Not_Pred_Income_1[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[6:6] <-       round(summary_stats$Opt_Not_Pred_Income_2[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[7:7] <-       round(summary_stats$Opt_Not_Pred_Income_3[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[8:8] <-       round(summary_stats$Opt_Not_Pred_Income_4[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[10:10] <-     round(summary_stats$Opt_Not_Pred_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[11:11] <- round(100-summary_stats$Opt_Not_Pred_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[12:12] <-     round(summary_stats$Opt_Not_Pred_NR[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[13:13] <-     round(summary_stats$Opt_Not_Pred_Correct [1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[14:14] <-     round(summary_stats$Opt_Not_Pred_Conseq [1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[15:15] <-     round(summary_stats$Opt_Not_Pred_InterviewTime[1:1],0)   # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[16:16] <-     round(summary_stats$Opt_Not_Pred_CC_time[1:1],2)   # Ensure the counts match the categories
table_df$Opt_Treatment_Not_Predicted[17:17] <-     round(summary_stats$Opt_Not_Pred_n[1:1],0)



table_df$Control_Predicted[2:2] <-       round(summary_stats$Control_Pred_Gender[1:1],2)  # Ensure the counts match the categories
table_df$Control_Predicted[3:3] <-       round(summary_stats$Control_Pred_Age[1:1],2)   # Ensure the counts match the categories
table_df$Control_Predicted[5:5] <-       round(summary_stats$Control_Pred_Income_1[1:1],2)   # Ensure the counts match the categories
table_df$Control_Predicted[6:6] <-       round(summary_stats$Control_Pred_Income_2[1:1],2)   # Ensure the counts match the categories
table_df$Control_Predicted[7:7] <-       round(summary_stats$Control_Pred_Income_3[1:1],2)   # Ensure the counts match the categories
table_df$Control_Predicted[8:8] <-       round(summary_stats$Control_Pred_Income_4[1:1],2)   # Ensure the counts match the categories
table_df$Control_Predicted[10:10] <-     round(summary_stats$Control_Pred_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Control_Predicted[11:11] <- round(100-summary_stats$Control_Pred_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Control_Predicted[12:12] <-     round(summary_stats$Control_Pred_NR[1:1],2)   # Ensure the counts match the categories
table_df$Control_Predicted[13:13] <-     round(summary_stats$Control_Pred_Correct [1:1],2)   # Ensure the counts match the categories
table_df$Control_Predicted[14:14] <-     round(summary_stats$Control_Pred_Conseq [1:1],2)   # Ensure the counts match the categories
table_df$Control_Predicted[15:15] <-     round(summary_stats$Control_Pred_InterviewTime[1:1],0)   # Ensure the counts match the categories
table_df$Control_Predicted[16:16] <-     round(summary_stats$Control_Pred_CC_time[1:1],2)   # Ensure the counts match the categories
table_df$Control_Predicted[17:17] <-     round(summary_stats$Control_Pred_n[1:1],0)

table_df$Control_Not_Predicted[2:2] <-       round(summary_stats$Control_Not_Pred_Gender[1:1],2)  # Ensure the counts match the categories
table_df$Control_Not_Predicted[3:3] <-       round(summary_stats$Control_Not_Pred_Age[1:1],2)   # Ensure the counts match the categories
table_df$Control_Not_Predicted[5:5] <-       round(summary_stats$Control_Not_Pred_Income_1[1:1],2)   # Ensure the counts match the categories
table_df$Control_Not_Predicted[6:6] <-       round(summary_stats$Control_Not_Pred_Income_2[1:1],2)   # Ensure the counts match the categories
table_df$Control_Not_Predicted[7:7] <-       round(summary_stats$Control_Not_Pred_Income_3[1:1],2)   # Ensure the counts match the categories
table_df$Control_Not_Predicted[8:8] <-       round(summary_stats$Control_Not_Pred_Income_4[1:1],2)   # Ensure the counts match the categories
table_df$Control_Not_Predicted[10:10] <-     round(summary_stats$Control_Not_Pred_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Control_Not_Predicted[11:11] <- round(100-summary_stats$Control_Not_Pred_UniDegree[1:1],2)   # Ensure the counts match the categories
table_df$Control_Not_Predicted[12:12] <-     round(summary_stats$Control_Not_Pred_NR[1:1],2)   # Ensure the counts match the categories
table_df$Control_Not_Predicted[13:13] <-     round(summary_stats$Control_Not_Pred_Correct [1:1],2)   # Ensure the counts match the categories
table_df$Control_Not_Predicted[14:14] <-     round(summary_stats$Control_Not_Pred_Conseq [1:1],2)   # Ensure the counts match the categories
table_df$Control_Not_Predicted[15:15] <-     round(summary_stats$Control_Not_Pred_InterviewTime[1:1],0)   # Ensure the counts match the categories
table_df$Control_Not_Predicted[16:16] <-     round(summary_stats$Control_Not_Pred_CC_time[1:1],2)   # Ensure the counts match the categories
table_df$Control_Not_Predicted[17:17] <-     round(summary_stats$Control_Not_Pred_n[1:1],0)

write.table(table_df, "Data/descriptives_long.txt", sep="\t")
xtable(table_df, include.rownames = F)
