# Load models
MXL_wtp_Control_Not_Pred_model <- apollo_loadModel("Estimation_results/mxl/prediction/Split_samples/MXL_wtp_Control_Not_Pred")
MXL_wtp_Control_Pred_model <- apollo_loadModel("Estimation_results/mxl/prediction/Split_samples/MXL_wtp_Control_Pred")
MXL_wtp_Opt_Not_Pred_model <- apollo_loadModel("Estimation_results/mxl/prediction/Split_samples/MXL_wtp_Opt_Not_Pred")
MXL_wtp_Opt_Pred_model <- apollo_loadModel("Estimation_results/mxl/prediction/Split_samples/MXL_wtp_Opt_Pred")
MXL_wtp_Treated_Not_Pred_model <- apollo_loadModel("Estimation_results/mxl/prediction/Split_samples/MXL_wtp_Treated_Not_Pred")
MXL_wtp_Treated_Pred_model <- apollo_loadModel("Estimation_results/mxl/prediction/Split_samples/MXL_wtp_Treated_Pred")

MXL_wtp_opt_treated <- apollo_loadModel("Estimation_results/mxl/Split_samples/MXL_wtp Vol_Treat")
MXL_wtp_opt_not_treated <- apollo_loadModel("Estimation_results/mxl/Split_samples/MXL_wtp Vol_Not_Treat")

mxl_tr <- apollo_loadModel("Estimation_results/mxl/Split_samples/MXL_wtp Treated A")
mxl_vol_tr <- apollo_loadModel("Estimation_results/mxl/Split_samples/MXL_wtp Vol_Treated A")
mxl_not_tr <- apollo_loadModel("Estimation_results/mxl/Split_samples/MXL_wtp Not_Treated A")

# List of models
models <- list(
  "Treated Not Pred" = MXL_wtp_Treated_Not_Pred_model,
  "Opt Not Pred" = MXL_wtp_Opt_Not_Pred_model,
  "Control Not Pred" = MXL_wtp_Control_Not_Pred_model,
  "Treated Pred" = MXL_wtp_Treated_Pred_model,
  "Opt Pred" = MXL_wtp_Opt_Pred_model,
  "Control Pred" = MXL_wtp_Control_Pred_model,
  "Opt No Info" = MXL_wtp_opt_not_treated,
  "Opt Info" = MXL_wtp_opt_treated,
  "Treated Split Sample" = mxl_tr,
  "Opt Split Sample" = mxl_vol_tr,
  "Control Split Sample" = mxl_not_tr
)

group_color_mapping <- c(
  "Control" = "grey",
  "Treated" = "red",
  "Optional" = "orange"
)

# Define line type mapping for prediction status
prediction_line_mapping <- c(
  "Not Predicted" = "dashed",
  "Predicted" = "solid",
  "Split Sample" = "dotted"
)

# Create a mapping for the groups
group_mapping <- c(
  "Control Not Pred" = "Control",
  "Control Pred" = "Control",
  "Treated Not Pred" = "Treated",
  "Treated Pred" = "Treated",
  "Opt Not Pred" = "Optional",
  "Opt Pred" = "Optional",
  "Opt No Info" = "Optional",
  "Opt Info" = "Optional",
  "Control Split Sample" = "Control",
  "Opt Split Sample" = "Optional",
  "Treated Split Sample" = "Treated"
)

# Create a mapping for prediction status
prediction_mapping <- c(
  "Control Not Pred" = "Not Predicted",
  "Control Pred" = "Predicted",
  "Control Split Sample" = "Split Sample",
  "Treated Not Pred" = "Not Predicted",
  "Treated Pred" = "Predicted",
  "Treated Split Sample" = "Split Sample",
  "Opt Not Pred" = "Not Predicted",
  "Opt Pred" = "Predicted",
  "Opt Split Sample" = "Split Sample",
  "Opt Info" = "Predicted",
  "Opt No Info" = "Not Predicted"
)

# Define the x-range for plotting (1000 values)
x_range <- seq(-20, 100, length.out = 1000)

# Define an empty data frame to store the results
plot_data <- data.frame()

# Loop through the models and calculate the density for each
for (i in seq_along(models)) {
  model_name <- names(models)[i]
  model <- models[[i]]
  
  # Extract mean and standard deviation for 'mu_natural' and 'sig_natural'
  coef <- model$estimate
  mean <- coef["mu_natural"]
  sd <- coef["sig_natural"]
  
  # Compute the normal distribution based on the extracted mean and sd
  y <- dnorm(x_range, mean, sd)
  
  # Create a data frame for this model and append it to the main data frame
  temp_data <- data.frame(
    x = x_range, 
    density = y, 
    model = model_name,
    Group = group_mapping[[model_name]],
    Prediction = prediction_mapping[[model_name]]
  )
  
  plot_data <- bind_rows(plot_data, temp_data)
}

# Plot using ggplot2 with custom color and linetype mappings
ggplot(plot_data, aes(x = x, y = density, color = Group, linetype = Prediction)) +
  geom_line(size = 1) + 
  scale_color_manual(values = group_color_mapping) +  # Set custom colors for groups
  scale_linetype_manual(values = prediction_line_mapping) +  # Set custom linetypes for prediction status
  labs(
    title = "Normal Distributions from Multiple MXL Models",
    x = "WTP Naturalness (€/month)",
    y = "Density",
    color = "Group",
    linetype = "Prediction"
  ) +
  theme_minimal() +
  theme(legend.position = "right")




#### Plot underneath

ggplot(plot_data, aes(x = x, y = density, color = Group, linetype = Prediction)) +
  geom_line(size = 1) + 
  scale_color_manual(values = group_color_mapping) +  # Set custom colors for groups
  scale_linetype_manual(values = prediction_line_mapping) +  # Set custom linetypes for prediction status
  facet_grid(Prediction ~ ., scales = "free_y") +  # Stacks "Not Predicted" on top of "Predicted"
  labs(
    title = "Normal Distributions from Multiple MXL Models",
    x = "WTP Naturalness (€/month)",
    y = "Density",
    color = "Group",
    linetype = "Prediction"
  ) +
  theme_minimal() +
  theme(
    legend.position = "right",
    strip.text.y = element_text(size = 12, face = "bold"),  # Adjust facet labels
    panel.spacing = unit(1, "lines")  # Adds space between the two facets
  ) +
  xlim(-25, 75)


#### Compare means
# Create an empty data frame
# Function to compute CI dynamically
calculate_ci <- function(mean, se, confidence = 0.95) {
  z_value <- qnorm((1 + confidence) / 2)  # Compute Z-score for the given confidence level
  lower_ci <- mean - z_value * se
  upper_ci <- mean + z_value * se
  return(c(lower_ci, upper_ci))
}

ci_data <- data.frame()

# Loop through each model and extract mean and confidence interval
for (i in seq_along(models)) {
  model_name <- names(models)[i]
  model <- models[[i]]
  
  # Extract mean estimate and robust standard error
  mean_value <- model$estimate["mu_natural"]
  se_robust <- model$robse["mu_natural"]
  
  # Compute 90% confidence intervals dynamically
  ci_values <- calculate_ci(mean_value, se_robust, confidence = 0.95)
  
  # Append to data frame
  temp_data <- data.frame(
    Model = model_name,
    Mean = mean_value,
    Lower_CI = ci_values[1],
    Upper_CI = ci_values[2],
    Group = group_mapping[[model_name]], 
    Prediction = prediction_mapping[[model_name]]
  )
  
  ci_data <- bind_rows(ci_data, temp_data)
}

# Ensure correct order of Groups (Treated > Optional > Control)
ci_data$Group <- factor(ci_data$Group, levels = c("Treated", "Optional", "Control"))
ci_data$Model <- factor(ci_data$Model, levels = unique(ci_data$Model))

model_order <- c(
  "Treated Not Pred", "Treated Pred", "Treated Split Sample",
  "Opt Not Pred", "Opt Pred", "Opt No Info", "Opt Info", "Opt Split Sample",
  "Control Not Pred", "Control Pred", "Control Split Sample"
)
ci_data$Model <- factor(ci_data$Model, levels = model_order)


ggplot(ci_data, aes(x = Model, y = Mean, color = Group)) +
  geom_point(size = 3, position = position_dodge(width = 0.5)) +  # Mean points
  geom_errorbar(aes(ymin = Lower_CI, ymax = Upper_CI), width = 0.2, position = position_dodge(width = 0.5)) +  # CI bars
  scale_color_manual(values = group_color_mapping) +  # Custom colors for groups
  facet_grid(Prediction ~ ., scales = "free_y") +  # Stack "Not Predicted" above "Predicted"
  coord_flip() +  # Flip axes for better readability
  labs(
    title = "Mean WTP Naturalness Estimates with 90% Confidence Intervals",
    x = "Model",
    y = "Mean Estimate (€/month)",
    color = "Group"
  ) +
  theme_minimal() +
  theme(
    legend.position = "right",
    strip.text.y = element_text(size = 12, face = "bold"),  # Adjust facet labels
    axis.text.y = element_text(size = 10)  # Ensure readable model names
  )


#### Do and plot z tests ####

# Function to calculate Z-test and confidence intervals
calculate_z_test <- function(model_1, model_2, coef="mu_natural") {
  mean_diff <- model_1$estimate[coef] - model_2$estimate[coef]
  se_diff <- sqrt(model_1$robse[coef]^2 + model_2$robse[coef]^2)
  
  # Compute confidence intervals
  lower_ci <- mean_diff - 1.96* se_diff
  upper_ci <- mean_diff + 1.96 * se_diff
  
  # Compute Z-score
  z_value <- mean_diff / se_diff
  p_value <- 2 * (1 - pnorm(abs(z_value)))  # Two-tailed p-value
  
  return(data.frame(
    Model1 = names(model_1$estimate[coef]),
    Model2 = names(model_2$estimate[coef]),
    Mean_Difference = mean_diff,
    Lower_CI = lower_ci,
    Upper_CI = upper_ci,
    Z_Value = z_value,
    P_Value = p_value
  ))
}

# Define groups
not_predicted_models <- models[names(models) %in% c("Treated Not Pred",  "Opt Not Pred", "Control Not Pred")]
predicted_models <- models[names(models) %in% c("Treated Pred", "Opt Pred", "Control Pred")]
split_sample_models <- models[names(models) %in% c("Treated Split Sample", "Opt Split Sample", "Control Split Sample")]


  
  # Function to perform Z-tests within a group while ensuring the correct order
  perform_z_tests_within_group <- function(model_group, group_name, coef="mu_natural") {
    model_names <- names(model_group)
    z_test_results <- data.frame()
    
    # Define the correct comparison order
    comparison_order <- c("Treated",  "Opt", "Control")  # Order: Treated vs Control, Treated vs Optional, Optional vs Control
    
    # Reorder the models according to the desired comparison order
    ordered_models <- model_group[order(match(sub(" .*", "", model_names), comparison_order))]
    
    # Perform Z-tests in the correct order
    for (i in seq_along(ordered_models)) {
      for (j in seq_along(ordered_models)) {
        if (i < j) {  # Avoid duplicate comparisons
          test_result <- calculate_z_test(ordered_models[[i]], ordered_models[[j]], coef=coef)
          test_result$Comparison <- paste(names(ordered_models)[i], "vs", names(ordered_models)[j])  # Add model pair label
          test_result$Group <- group_name  # Label the group
          z_test_results <- bind_rows(z_test_results, test_result)
        }
      }
    }
    return(z_test_results)
  }
  
  # Function to perform cross-group tests while ensuring "Predicted vs Not Predicted"
  perform_cross_group_tests <- function(not_predicted, predicted, coef="mu_natural") {
    z_test_results <- data.frame()
    comparison_order <- c("Treated",  "Optional", "Control")  # Ensure correct order
    
    category_map <- list(
      "Treated Pred" = "Treated Not Pred",
      "Opt Pred" = "Opt Not Pred",
      "Control Pred" = "Control Not Pred"
    )
    
    # Sort models based on the predefined comparison order
    ordered_predicted <- predicted[order(match(sub(" .*", "", names(predicted)), comparison_order))]
    ordered_not_predicted <- not_predicted[order(match(sub(" .*", "", names(not_predicted)), comparison_order))]
    
    for (cat_pred in names(category_map)) {
      cat_not_pred <- category_map[[cat_pred]]
      
      if (cat_pred %in% names(ordered_predicted) & cat_not_pred %in% names(ordered_not_predicted)) {
        test_result <- calculate_z_test(ordered_predicted[[cat_pred]], ordered_not_predicted[[cat_not_pred]], coef=coef)
        test_result$Comparison <- paste(cat_pred, "vs", cat_not_pred)  # Now "Predicted vs Not Predicted"
        test_result$Group <- "Predicted vs Not Predicted"
        z_test_results <- bind_rows(z_test_results, test_result)
      }
    }
    
    return(z_test_results)
  }
  
  # Perform Z-tests within each group while enforcing the correct order
  coefficients_to_test <- c("mu_natural", "mu_walking", "mu_rent", "ASC_1", "ASC_2")
  #coefficients_to_test <- c("sig_natural", "sig_walking", "sig_rent", "sig_ASC_1", "sig_ASC_2") # test sds

  
  ##### For all 
  # Within groups
  z_tests_not_predicted <- perform_z_tests_within_group(not_predicted_models, "Not Predicted", coefficients_to_test)
  z_tests_predicted <- perform_z_tests_within_group(predicted_models, "Predicted", coefficients_to_test)
  z_tests_split_sample <- perform_z_tests_within_group(split_sample_models, "Split Sample", coefficients_to_test)
  
  # Cross-group
  z_tests_cross_group <- perform_cross_group_tests(not_predicted_models, predicted_models, coefficients_to_test)
  
################ Do Plots #########
  # Combine all Z-test results
  z_test_results_all <- bind_rows(
    z_tests_not_predicted, 
    z_tests_predicted, 
    z_tests_split_sample, 
    z_tests_cross_group
  )
  
  # Add significance column
  z_test_results_all$Significant <- ifelse(z_test_results_all$P_Value < 0.05, "Significant", "Not Significant")
  
  # Ensure correct ordering of groups (Not Predicted → Predicted → Split Sample → Predicted vs Not Predicted)
  z_test_results_all$Group <- factor(z_test_results_all$Group, levels = c("Not Predicted", "Predicted", "Split Sample", "Predicted vs Not Predicted"))
  
  # Separate groups for visualization
  z_test_results_within <- z_test_results_all %>% filter(Group %in% c("Not Predicted", "Predicted"))
  z_test_results_splits <- z_test_results_all %>% filter(Group %in% c("Split Sample"))
  z_test_results_cross <- z_test_results_all %>% filter(Group == "Predicted vs Not Predicted")
  

  


  
  z_test_results_all <- z_test_results_all %>%
    mutate(
      Coefficient = sub("\\.+\\d+", "", rownames(z_test_results_all)),  # Clean coefficient names
      Significant = ifelse(P_Value < 0.05, "Statistically significant difference", "No statistically significant difference")
    )  
  
  
  ggplot(z_test_results_all, aes(x = reorder(Comparison, Mean_Difference), y = Mean_Difference, color = Significant)) +
    geom_point(size = 3) +
    geom_errorbar(aes(ymin = Lower_CI, ymax = Upper_CI), width = 0.2) +
    geom_hline(yintercept = 0, linetype = "dashed", color = "gray50") +
    scale_color_manual(values = c("Statistically significant difference" = "red", "No statistically significant difference" = "grey")) +
    coord_flip() +
    facet_grid(Group ~ Coefficient, scales = "free", space = "free_y") +
    labs(
      x = "Model Comparisons",
      y = "Mean Difference",
      color = "Significance"
    ) +
    theme_bw() +
    theme(
      strip.text = element_text(face = "bold"),
      legend.position = "bottom",
      panel.spacing = unit(0.8, "lines")
    )
  
#### Only ASC and rent for appendix
  z_test_results_appendix <- z_test_results_all %>%
    filter(!Coefficient %in% c("mu_natural", "mu_walking"))
  
  ggplot(z_test_results_appendix, aes(x = factor(Comparison, level=c("Treated Not Pred vs Opt Not Pred", "Opt Not Pred vs Control Not Pred",
                                                                      "Treated Not Pred vs Control Not Pred", "Treated Pred vs Opt Pred",
                                                                        "Opt Pred vs Control Pred", "Treated Pred vs Control Pred",
                                                                        "Treated Split Sample vs Opt Split Sample", "Opt Split Sample vs Control Split Sample",
                                                                     "Treated Split Sample vs Control Split Sample", "Control Pred vs Control Not Pred",
                                                                     "Opt Pred vs Opt Not Pred","Treated Pred vs Treated Not Pred"
                                                                     )), y = Mean_Difference, color = Significant)) +
    geom_point(size = 3) +
    geom_errorbar(aes(ymin = Lower_CI, ymax = Upper_CI), width = 0.2) +
    geom_hline(yintercept = 0, linetype = "dashed", color = "gray50") +
    scale_color_manual(values = c("Statistically significant difference" = "red", "No statistically significant difference" = "grey")) +
    coord_flip() +
    facet_grid(Group ~ Coefficient, scales = "free", space = "free_y") +
    labs(
      x = "Model Comparisons",
      y = "Mean Difference",
      color = "Significance"
    ) +
    theme_bw() +
    theme(
      strip.text = element_text(face = "bold"),
      legend.position = "bottom",
      panel.spacing = unit(0.8, "lines")
    )
  
  
  ggsave("Figures/z_test_appendix.png", width=12, height=10, dpi="print")

  z_test_results_split_nat_wd <- z_test_results_all %>%
   filter(Coefficient %in% c("mu_natural", "mu_walking")) %>% filter(Group=="Split Sample") %>%  mutate(Comparison = case_when(
     grepl("Treated Split Sample vs Control Split Sample", Comparison) ~ "Treated vs Control",
     grepl("Opt Split Sample vs Control Split Sample", Comparison) ~ "Optional vs Control",
     grepl("Treated Split Sample vs Opt Split Sample", Comparison) ~ "Treated vs Optional",
     TRUE ~ Comparison  # Keep original if not matched
   ))
  
  
  ggplot(z_test_results_split_nat_wd, aes(x = factor(Comparison, level=c("Treated vs Optional", "Optional vs Control","Treated vs Control")), y = Mean_Difference, color = Significant)) +
    geom_point(size = 3) +
    geom_errorbar(aes(ymin = Lower_CI, ymax = Upper_CI), width = 0.2) +
    geom_hline(yintercept = 0, linetype = "dashed", color = "gray50") +
    scale_color_manual(values = c("Statistically significant difference" = "red", "No statistically significant difference" = "grey")) +
    coord_flip() +
    facet_grid(Group ~ Coefficient, scales = "free", space = "free_y",
               labeller = labeller(
                 Coefficient = c(
                   "mu_natural" = "Naturalness",
                   "mu_walking" = "Walking Distance"))) +
    labs(
      x = "",
      y = "Mean Difference",
      color = "Significance"
    ) +
    theme_bw() +
    theme(
      strip.text = element_text(face = "bold"),
      legend.position = "bottom",
      panel.spacing = unit(0.8, "lines")
    )
  
  ggsave("Figures/z_test_split_samples.png", width=8, height=5, dpi="print")
  
  
  z_test_results_pred_nat_wd <- z_test_results_all %>%
    filter(Coefficient %in% c("mu_natural", "mu_walking")) %>% filter(Group %in% c("Predicted", "Not Predicted")) %>%  mutate(Comparison = case_when(
      grepl("Treated Split Sample vs Control Split Sample", Comparison) ~ "Treated vs Control",
      grepl("Treated Split Sample vs Opt Split Sample", Comparison) ~ "Treated vs Optional",
      grepl("Control Split Sample vs Opt Split Sample", Comparison) ~ "Control vs Optional",
      TRUE ~ Comparison  # Keep original if not matched
    ))
  
  ggplot(z_test_results_pred_nat_wd, aes(x = factor(Comparison, level=c("Treated Not Pred vs Opt Not Pred", "Opt Not Pred vs Control Not Pred",
                                                                        "Treated Not Pred vs Control Not Pred", "Treated Pred vs Opt Pred",
                                                                        "Opt Pred vs Control Pred", "Treated Pred vs Control Pred")), y = Mean_Difference, color = Significant)) +
    geom_point(size = 3) +
    geom_errorbar(aes(ymin = Lower_CI, ymax = Upper_CI), width = 0.2) +
    geom_hline(yintercept = 0, linetype = "dashed", color = "gray50") +
    scale_color_manual(values = c("Statistically significant difference" = "red", "No statistically significant difference" = "grey")) +
    coord_flip() +
    facet_grid(Group ~ Coefficient, scales = "free", space = "free_y",
               labeller = labeller(
                 Coefficient = c(
                   "mu_natural" = "Naturalness",
                   "mu_walking" = "Walking Distance"))) +
    labs(
      x = "",
      y = "Mean Difference",
      color = "Significance"
    ) +
    theme_bw() +
    theme(
      strip.text = element_text(face = "bold"),
      legend.position = "bottom",
      panel.spacing = unit(0.8, "lines")
    )
  
  ggsave("Figures/z_test_predictions_between.png", width=9, height=5, dpi="print")
  
  
  z_test_results_pred_vs_nat_wd <- z_test_results_all %>%
    filter(Coefficient %in% c("mu_natural", "mu_walking")) %>% filter(Group %in% c("Predicted vs Not Predicted")) %>%  mutate(Comparison = case_when(
      grepl("Treated Split Sample vs Control Split Sample", Comparison) ~ "Treated vs Control",
      grepl("Treated Split Sample vs Opt Split Sample", Comparison) ~ "Treated vs Optional",
      grepl("Control Split Sample vs Opt Split Sample", Comparison) ~ "Control vs Optional",
      TRUE ~ Comparison  # Keep original if not matched
    ))
  
  ggplot(z_test_results_pred_vs_nat_wd, aes(x = factor(Comparison, level=c("Control Pred vs Control Not Pred", "Opt Pred vs Opt Not Pred","Treated Pred vs Treated Not Pred")), y = Mean_Difference, color = Significant)) +
    geom_point(size = 3) +
    geom_errorbar(aes(ymin = Lower_CI, ymax = Upper_CI), width = 0.2) +
    geom_hline(yintercept = 0, linetype = "dashed", color = "gray50") +
    scale_color_manual(values = c("Statistically significant difference" = "red", "No statistically significant difference" = "grey")) +
    coord_flip() +
    facet_grid(Group ~ Coefficient, scales = "free", space = "free_y",
               labeller = labeller(
                 Coefficient = c(
                   "mu_natural" = "Naturalness",
                   "mu_walking" = "Walking Distance"))) +
    labs(
      x = "",
      y = "Mean Difference",
      color = "Significance"
    ) +
    theme_bw() +
    theme(
      strip.text = element_text(face = "bold"),
      legend.position = "bottom",
      panel.spacing = unit(0.8, "lines")
    )
  
  ggsave("Figures/z_test_predictions.png", width=8, height=5, dpi="print")
  